NodeType

Enum NodeType 

pub enum NodeType {
Show 16 variants BoolTrue, BoolFalse, Number, Char, String, MultilineString, Tuple, List, Record, Label, VariantWithPayload, OptionSome, OptionNone, ResultOk, ResultErr, Flags,
}
The type of a WAVE AST Node.

Variants



BoolTrue

Boolean true



BoolFalse

Boolean false



Number

Number May be an integer or float, including nan, inf, -inf



Char

Char Span includes delimiters.



String

String Span includes delimiters.



MultilineString

Multiline String Span includes delimiters.



Tuple

Tuple Child nodes are the tuple values.



List

List Child nodes are the list values.



Record

Record Child nodes are field Label, value pairs, e.g. [<field 1>, <value 1>, <field 2>, <value 2>, ...]



Label

Label In value position may represent an enum value or variant case (without payload).



VariantWithPayload

Variant case with payload Child nodes are variant case Label and payload value.



OptionSome

Option some Child node is the payload value.



OptionNone

Option none



ResultOk

Result ok Has zero or one child node for the payload value.



ResultErr

Result err Has zero or one child node for the payload value.



Flags

Flags Child nodes are flag Labels.